"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class DocumentFileUpdateTypedDict(TypedDict):
    status: str


class DocumentFileUpdate(BaseModel):
    status: str
