"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from enum import Enum


class ConnectorSource(str, Enum):
    BACKBLAZE = "backblaze"
    CONFLUENCE = "confluence"
    DROPBOX = "dropbox"
    FRESHDESK = "freshdesk"
    ONEDRIVE = "onedrive"
    GOOGLE_DRIVE = "google_drive"
    GMAIL = "gmail"
    NOTION = "notion"
    SALESFORCE = "salesforce"
    SHAREPOINT = "sharepoint"
    JIRA = "jira"
    SLACK = "slack"
    S3 = "s3"
    GCS = "gcs"
    HUBSPOT = "hubspot"
    ZENDESK = "zendesk"
