"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class PartitionStatsTypedDict(TypedDict):
    pages_processed_monthly: float
    pages_hosted_monthly: float
    pages_processed_total: float
    pages_hosted_total: float
    document_count: int


class PartitionStats(BaseModel):
    pages_processed_monthly: float

    pages_hosted_monthly: float

    pages_processed_total: float

    pages_hosted_total: float

    document_count: int
