"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class WordTimestampTypedDict(TypedDict):
    start_time: float
    end_time: float
    word: str
    probability: float


class WordTimestamp(BaseModel):
    start_time: float

    end_time: float

    word: str

    probability: float
