"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .deleteconnectionpayload import (
    DeleteConnectionPayload,
    DeleteConnectionPayloadTypedDict,
)
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class DeleteConnectionConnectionsConnectionIDDeletePostRequestTypedDict(TypedDict):
    connection_id: str
    delete_connection_payload: DeleteConnectionPayloadTypedDict


class DeleteConnectionConnectionsConnectionIDDeletePostRequest(BaseModel):
    connection_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    delete_connection_payload: Annotated[
        DeleteConnectionPayload,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
