"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .connectionbase import ConnectionBase, ConnectionBaseTypedDict
from ragie.types import BaseModel
from ragie.utils import FieldMetadata, PathParamMetadata, RequestMetadata
from typing_extensions import Annotated, TypedDict


class UpdateConnectionConnectionsConnectionIDPutRequestTypedDict(TypedDict):
    connection_id: str
    connection_base: ConnectionBaseTypedDict


class UpdateConnectionConnectionsConnectionIDPutRequest(BaseModel):
    connection_id: Annotated[
        str, FieldMetadata(path=PathParamMetadata(style="simple", explode=False))
    ]

    connection_base: Annotated[
        ConnectionBase,
        FieldMetadata(request=RequestMetadata(media_type="application/json")),
    ]
