"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class ConnectionStatsTypedDict(TypedDict):
    document_count: int
    page_count: float


class ConnectionStats(BaseModel):
    document_count: int

    page_count: float
