"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from ragie.types import BaseModel
from typing_extensions import TypedDict


class LinkTypedDict(TypedDict):
    href: str
    type: str


class Link(BaseModel):
    href: str

    type: str
