"""Code generated by Speakeasy (https://speakeasy.com). DO NOT EDIT."""

from __future__ import annotations
from .pagination import Pagination, PaginationTypedDict
from .partition import Partition, PartitionTypedDict
from ragie.types import BaseModel
from typing import List
from typing_extensions import TypedDict


class PartitionListTypedDict(TypedDict):
    pagination: PaginationTypedDict
    partitions: List[PartitionTypedDict]


class PartitionList(BaseModel):
    pagination: Pagination

    partitions: List[Partition]
